@@ -34,6 +34,7 @@ from typing import (
     Optional,
 )
 
+from deprecation import deprecated
 from mpservice.util import MAX_THREADS, get_shared_thread_pool
 from overrides import EnforceOverrides
 from tqdm.auto import tqdm
@@ -176,7 +177,7 @@ class Upath(abc.ABC, EnforceOverrides):
     def _run_in_executor(
         self,
         tasks: Iterable[tuple[Callable, tuple, dict, str]],
-        quiet: bool = False,
+        quiet: bool,
     ):
         """
         This method is used to run multiple I/O jobs concurrently, e.g.
@@ -541,6 +542,10 @@ class Upath(abc.ABC, EnforceOverrides):
         Parent "directories" are created as needed, if applicable.
 
         If ``overwrite`` is ``False`` and the current file exists, ``FileExistsError`` is raised.
+
+        ``data`` is either "byte-like" (such as bytes, bytearray, memoryview) or "file-like"
+        open in "binary" mode. In the second case, the file should be positioned at the beginning
+        (such as by calling ``.seek(0)``.)
         """
         raise NotImplementedError
 
@@ -667,6 +672,7 @@ class Upath(abc.ABC, EnforceOverrides):
         """
         return ZstdPickleSerializer.deserialize(self.read_bytes(), **kwargs)
 
+    @deprecated(deprecated_in="0.7.3", removed_in="0.7.6")
     def write_orjson(self, data: Any, *, overwrite=False, **kwargs) -> None:
         """
         ``overwrite`` is passed to :meth:`write_bytes`.
@@ -677,12 +683,14 @@ class Upath(abc.ABC, EnforceOverrides):
             OrjsonSerializer.serialize(data, **kwargs), overwrite=overwrite
         )
 
+    @deprecated(deprecated_in="0.7.3", removed_in="0.7.6")
     def read_orjson(self, **kwargs) -> Any:
         """
         ``**kwargs`` are passed to :meth:`serializer.OrjsonSerializer.deserialize`.
         """
         return OrjsonSerializer.deserialize(self.read_bytes(), **kwargs)
 
+    @deprecated(deprecated_in="0.7.3", removed_in="07.6")
     def write_orjson_z(self, data: Any, *, overwrite=False, **kwargs) -> None:
         """
         ``overwrite`` is passed to :meth:`write_bytes`.
@@ -693,12 +701,14 @@ class Upath(abc.ABC, EnforceOverrides):
             ZOrjsonSerializer.serialize(data, **kwargs), overwrite=overwrite
         )
 
+    @deprecated(deprecated_in="0.7.3", removed_in="0.7.6")
     def read_orjson_z(self, **kwargs) -> Any:
         """
         ``**kwargs`` are passed to :meth:`serializer.ZOrjsonSerializer.deserialize`.
         """
         return ZOrjsonSerializer.deserialize(self.read_bytes(), **kwargs)
 
+    @deprecated(deprecated_in="0.7.3", removed_in="0.7.6")
     def write_orjson_zstd(self, data: Any, *, overwrite=False, **kwargs) -> None:
         """
         ``overwrite`` is passed to :meth:`write_bytes`.
@@ -709,6 +719,7 @@ class Upath(abc.ABC, EnforceOverrides):
             ZstdOrjsonSerializer.serialize(data, **kwargs), overwrite=overwrite
         )
 
+    @deprecated(deprecated_in="0.7.3", removed_in="0.7.6")
     def read_orjson_zstd(self, **kwargs) -> Any:
         """
         ``**kwargs`` are passed to :meth:`serializer.ZstdOrjsonSerializer.deserialize`.
@@ -852,13 +863,8 @@ class Upath(abc.ABC, EnforceOverrides):
             for p in self.riterdir():
                 yield p.remove_file, [], {}, str(p.path.relative_to(self.path))
 
-        if quiet:
-            desc = False
-        else:
-            desc = f"Removing {self!r}"
-
         n = 0
-        for _ in self._run_in_executor(foo(), desc):
+        for _ in self._run_in_executor(foo(), quiet):
             n += 1
         return n
 
@@ -949,7 +955,8 @@ class Upath(abc.ABC, EnforceOverrides):
     @contextlib.contextmanager
     @abc.abstractmethod
     def lock(self, *, timeout: int = None):
-        """Lock the current file (i.e. ``self``), in order to have exclusive access.
+        """Lock the current file (i.e. ``self``), in order to have exclusive access to the code block
+        that has possesion of the lock.
 
         ``timeout``: if the lock can't be acquired within ``timeout`` seconds,
         ``LockAcquireError`` is raised. If ``None``, wait for a default
@@ -962,8 +969,6 @@ class Upath(abc.ABC, EnforceOverrides):
         lock itself. Actual waiting time could be slightly longer or shorter.
 
         This is a "mandatory lock", as opposed to an "advisory lock".
-        However, this API does not specify that the locked file
-        can be accessed for its content or used in any particular way.
         The intended use case is for this lock to be used
         for implementing a (cooperative) "code lock".
 
@@ -982,7 +987,7 @@ class Upath(abc.ABC, EnforceOverrides):
 
             yield self
 
-        One way to achive cooperative locking on a file via this mandatory
+        One way to achive cooperative locking on a file via this
         lock is like this::
 
             f = Upath('abc.txt')
@@ -995,8 +1000,11 @@ class Upath(abc.ABC, EnforceOverrides):
                 # (or in another block that deliberately uses the same file lock).
                 # Reading can be made exclusive by this same lock mechanism.
 
-        The lock file itself (i.e. `self`) is never used for its content;
-        the file is merely a dummy to implement the lock mechanism.
+        .. note:: This method should always be called on an "auxiliary file" (like in the example above),
+          whose sole purpose is to implement the lock; the file being locked should not be used for any other purpose.
+
+        .. note:: Just before exiting the context manager, the implementation should
+          delete the lock file.
 
         Some storage engines may not provide the capability to implement
         this lock.
