@@ -335,10 +335,14 @@ class GcsBlobUpath(BlobUpath):
         The case where ``data`` is a ``BufferedReader`` object, such as an open file,
         is not well tested.
         """
-        if isinstance(data, bytes):
+        try:
+            memoryview(data)
+        except TypeError:  # file-like data
+            self._write_from_buffer(
+                data, content_type="text/plain", overwrite=overwrite
+            )
+        else:  # bytes-like data
             self._blob_rate_limit(self._write_bytes, data, overwrite=overwrite)
-            return
-        self._write_from_buffer(data, content_type="text/plain", overwrite=overwrite)
 
     def _read_into_buffer(self, file_obj):
         file_info = self.file_info()
@@ -381,11 +385,7 @@ class GcsBlobUpath(BlobUpath):
                 if k >= file_size:
                     break
 
-        if self._quiet_multidownload:
-            desc = False
-        else:
-            desc = f"Downloading {self!r}"
-        for buf, k in self._run_in_executor(_do_download(), desc):
+        for buf, k in self._run_in_executor(_do_download(), self._quiet_multidownload):
             n = file_obj.write(buf.getbuffer())
             if n != k:
                 raise BufferError(
@@ -665,7 +665,7 @@ class GcsBlobUpath(BlobUpath):
                     self._blob_rate_limit(
                         self._blob().delete,
                         client=self._client(),
-                        if_generation_match=self._generation,
+                        if_generation_match=self._generation,  # TODO: should we remove this condition?
                     )
                 except Exception as e:
                     raise LockReleaseError(f"failed to delete lock file {self}") from e
